#!/usr/bin/perl -w -I/usr/sausalito/perl -I/usr/sausalito/handlers/base/shell
# $Id: vsite_shell.pl,v 1.2 2001/11/05 08:16:41 pbose Exp $
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
#
# toggle shell access on and off for all site users when the vsite
#

use CCE;
use Base::User qw(usermod);
use MyShell;
use Base::Vsite qw(vsite_update_site_admin_caps);

my $cce = new CCE;
$cce->connectfd();

my $vsite = $cce->event_object();
my ($ok, $shell) = $cce->get($cce->event_oid(), 'Shell');
if (!$ok)
{
    $cce->bye('FAIL', '[[base-shell.cantReadVsiteShell]]');
    exit(1);
}

# if the vsite is suspended or shell is turned off, disable shell for
# all users
my @usermods = ();
my $fail_msg = '';
if ($vsite->{suspend} || !$shell->{enabled})
{
    $fail_msg = '[[base-shell.cantDisableVsiteShell]]';
    my $new_shell = ($vsite->{suspend} 
                            ? $MyShell::SUSPEND_SHELL : $MyShell::BAD_SHELL);

    # don't toggle the User.Shell.enabled property, because it should
    # be restored if the site is given shell access again
    my @users = $cce->find('User', { 'site' => $vsite->{name} });
    for my $oid (@users)
    {
        ($ok, my $user) = $cce->get($oid);
        if (!$ok)
        {
            $cce->bye('FAIL', '[[base-shell.cantReadVsiteUser]]');
            exit(1);
        }

        push @usermods, { 'name' => $user->{name}, 'shell' => $new_shell };
    } # got all users
}
elsif ($shell->{enabled})
{
    $fail_msg = '[[base-shell.cantEnableVsiteShell]]';
    # enable shell for all users, who have been given shell access
    my @users = $cce->find('User', { 'site' => $vsite->{name} });
    for my $oid (@users)
    {
        ($ok, my $user) = $cce->get($oid);
        ($ok, my $user_shell) = $cce->get($oid, 'Shell');
        if (!$ok)
        {
            $cce->bye('FAIL', '[[base-shell.cantReadVsiteUser]]');
            exit(1);
        }
        
        my $new_shell = $MyShell::BAD_SHELL;
        if ($user_shell->{enabled})
        {
            $new_shell = $MyShell::GOOD_SHELL;
        }
        
        push @usermods, {
                            'name' => $user->{name},
                            'shell' => $new_shell
                            };
    } # got all site users
}

if (scalar(@usermods) && !(usermod(\@usermods))[0])
{
    $cce->bye('FAIL', $fail_msg);
    exit(1);
}

# update site admin caps
if (!$cce->event_is_destroy()){
	vsite_update_site_admin_caps($cce, $vsite, 'siteShell', $shell->{enabled});
}

$cce->bye('SUCCESS');
exit(0);
